==> resiprocate_1.8.2.orig.tar.gz: resiprocate-1.8.2/apps/sipdial/sipdialer.cpp <==

#include <cstdlib>
#include <fstream>
#include <iostream>
#include <string>

#include "resip/stack/NameAddr.hxx"
#include "resip/stack/Uri.hxx"
#include "rutil/Data.hxx"

#include "DialerConfiguration.hxx"
#include "DialInstance.hxx"

using namespace resip;
using namespace std;

string getFullFilename()
{
#ifdef WIN32
   char *home_drive = getenv("HOMEDRIVE");
   assert(home_drive); // FIXME
   char *home_path = getenv("HOMEPATH");
   assert(home_path); // FIXME
   string full_filename(string(home_drive) + string(home_dir) + string("\sipdial\sipdial.cfg"));
   return full_filename;
#else   
   char *home_dir = getenv("HOME");
   assert(home_dir); // FIXME
   string full_filename(string(home_dir) + string("/.sipdial/sipdial.cfg"));
   return full_filename;
#endif
}

int main(int argc, char *argv[]) 
{
   if(argc != 2)
      // FIXME
      assert(0);
   
   DialerConfiguration *dc = new DialerConfiguration();
   ifstream in(getFullFilename().c_str());
   if(!in.is_open())
      assert(0); // FIXME

   dc->loadStream(in);
   in.close();
   
   DialInstance di(*dc, Uri(Data(argv[1])));
   di.execute();

}


/* ====================================================================
 *
 * Copyright 2012 Daniel Pocock.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. Neither the name of the author(s) nor the names of any contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR(S) AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * ====================================================================
 *
 *
 */

==> resiprocate_1.9.7.orig.tar.gz: resiprocate-1.9.7/apps/sipdial/sipdialer.cpp <==

#include <cstdlib>
#include <fstream>
#include <iostream>
#include <string>

#include "resip/stack/NameAddr.hxx"
#include "resip/stack/Uri.hxx"
#include "rutil/Data.hxx"

#include "DialerConfiguration.hxx"
#include "DialInstance.hxx"

using namespace resip;
using namespace std;

Data getFullFilename()
{
#ifdef WIN32
   char *home_drive = getenv("HOMEDRIVE");
   assert(home_drive); // FIXME
   char *home_path = getenv("HOMEPATH");
   assert(home_path); // FIXME
   Data full_filename(string(home_drive) + string(home_dir) + string("\sipdial\sipdial.cfg"));
   return full_filename;
#else   
   char *home_dir = getenv("HOME");
   assert(home_dir); // FIXME
   Data full_filename(string(home_dir) + string("/.sipdial/sipdial.cfg"));
   return full_filename;
#endif
}

int main(int argc, char *argv[]) 
{
   Data defaultConfig(getFullFilename());
   DialerConfiguration dc;
   dc.parseConfig(argc, argv, defaultConfig, 1);

   Data targetUri(argv[1]);
   
   DialInstance di(dc, Uri(targetUri));
   di.execute();

}


/* ====================================================================
 *
 * Copyright 2012 Daniel Pocock.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. Neither the name of the author(s) nor the names of any contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR(S) AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * ====================================================================
 *
 *
 */
